#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 tasty-inspection-testing
version:              0.2.1
visibility:           public
id:                   tasty-inspection-testing-0.2.1-ETs58qsBRhT8mXPYyoygSJ
key:                  tasty-inspection-testing-0.2.1-ETs58qsBRhT8mXPYyoygSJ
license:              MIT
copyright:            2017 Joachim Breitner, 2021 Andrew Lelechenko
maintainer:           Andrew Lelechenko <andrew.lelechenko@gmail.com>
author:               Joachim Breitner, Andrew Lelechenko
homepage:             https://github.com/Bodigrim/tasty-inspection-testing
synopsis:             Inspection testing support for tasty
description:          Integrate @inspection-testing@ into @tasty@ test suites.
category:             Testing
abi:                  0a5c510f44e25c01ec57a19326bee0f1
exposed:              True
exposed-modules:      Test.Tasty.Inspection Test.Tasty.Inspection.Plugin
hidden-modules:       Test.Tasty.Inspection.Internal
import-dirs:
    /usr/lib/ghc-9.6.6/site-local/tasty-inspection-testing-0.2.1

library-dirs:
    /usr/lib/ghc-9.6.6/site-local/tasty-inspection-testing-0.2.1

library-dirs-static:
    /usr/lib/ghc-9.6.6/site-local/tasty-inspection-testing-0.2.1

dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-tasty-inspection-testing
hs-libraries:         HStasty-inspection-testing-0.2.1-ETs58qsBRhT8mXPYyoygSJ
depends:
    base-4.18.2.1 ghc-9.6.6
    inspection-testing-0.6.2-47cxnEk6Ffx5w0meYrAP5F
    tasty-1.5.2-IM2bl9bLJtCFnmvQ3jLhCm template-haskell-2.20.0.0

haddock-interfaces:
    /usr/share/doc/haskell-tasty-inspection-testing/html/tasty-inspection-testing.haddock

haddock-html:         /usr/share/doc/haskell-tasty-inspection-testing/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

